@@ -1,13 +1,11 @@
 package App::optex::textconv;
 
-use 5.014;
-use strict;
+our $VERSION = '0.09';
+
+use v5.14;
 use warnings;
-
 use Encode;
 
-our $VERSION = "0.08";
-
 =encoding utf-8
 
 =head1 NAME
@@ -16,7 +14,7 @@ textconv - optex module to replace document file by its text contents
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
@@ -185,7 +183,7 @@ sub textconv {
 		}
 	    };
 	    use App::optex::Tmpfile;
-	    my $tmp = $persist[@persist] = new App::optex::Tmpfile;
+	    my $tmp = $persist[@persist] = App::optex::Tmpfile->new;
 	    my $data = do {
 		no strict 'refs';
 		use charnames ':full';
