@@ -1,10 +1,9 @@
 package App::optex::textconv::msdoc;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
-use strict;
-use warnings;
 use v5.14;
+use warnings;
 use Carp;
 use utf8;
 
@@ -33,6 +32,13 @@ my %param = (
     pptx => { space => 1, separator => ""   },
     );
 
+my $replace_reference = do {
+    my %hash = qw( amp &  lt <  gt > );
+    my @keys = keys %hash;
+    my $re = do { local $" = '|'; qr/&(@keys);/ };
+    sub { s/$re/$hash{$1}/g }
+};
+
 sub _xml2text {
     local $_ = shift;
     my $type = shift;
@@ -43,21 +49,29 @@ sub _xml2text {
 	my $p = $+{para};
 	my @s;
 	while ($p =~ m{
+	       (?<tab> <w:tab/> | <w:tabs> )
+	       |
 	       <(?<tag>(?:[apw]:)?t)\b[^>]*> (?<text>[^<]*?) </\g{tag}>
 	       }xsg) {
-	    push @s, $+{text} if $+{text} ne '';
+	    if ($+{tab}) {
+		push @s, "  ";
+	    } else {
+		push @s, $+{text} if $+{text} ne '';
+	    }
 	}
 	@s or next;
 	push @p, join($param->{separator}, @s) . ("\n" x $param->{space});
     }
-    join '', @p;
+    my $text = join '', @p;
+    $replace_reference->() for $text;
+    $text;
 }
 
 use App::optex::textconv::Zip;
 
 sub to_text {
     my $zipfile = shift;
-    my $zip = new App::optex::textconv::Zip $zipfile;
+    my $zip = App::optex::textconv::Zip->new($zipfile);
     my $type = $zip->suffix or return;
     join "\n", map {
 	my $text = extract_text $zip->extract($_), $type;
